@@ -1816,7 +1816,9 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         b0 = self.textbuffer[src]
         it = b0.get_iter_at_line_or_eof(chunk[1])
         if chunk[2] >= b0.get_line_count():
-            it.backward_char()
+            # If this is the end of the buffer, we need to remove the
+            # previous newline, because the current line has none.
+            it.backward_cursor_position()
         b0.delete(it, b0.get_iter_at_line_or_eof(chunk[2]))
         mark0 = b0.create_mark(None, it, True)
         mark1 = b0.create_mark(None, it, True)
