@@ -214,6 +214,7 @@ def get_common_theme():
         "delete": lookup("meld:insert", "background"),
         "conflict": lookup("meld:conflict", "background"),
         "replace": lookup("meld:replace", "background"),
+        "error": lookup("meld:error", "background"),
         "current-chunk-highlight": lookup(
             "meld:current-chunk-highlight", "background")
     }
@@ -222,14 +223,11 @@ def get_common_theme():
         "delete": lookup("meld:insert", "line-background"),
         "conflict": lookup("meld:conflict", "line-background"),
         "replace": lookup("meld:replace", "line-background"),
+        "error": lookup("meld:error", "line-background"),
     }
     return fill_colours, line_colours
 
 
-def gdk_to_cairo_color(color):
-    return (color.red / 65535., color.green / 65535., color.blue / 65535.)
-
-
 def all_same(lst):
     """Return True if all elements of the list are equal"""
     return not lst or lst.count(lst[0]) == len(lst)
@@ -384,12 +382,6 @@ def copytree(src, dst):
             raise
 
 
-def shell_escape(glob_pat):
-    # TODO: handle all cases
-    assert not re.compile(r"[][*?]").findall(glob_pat)
-    return glob_pat.replace('{', '[{]').replace('}', '[}]')
-
-
 def shell_to_regex(pat):
     """Translate a shell PATTERN to a regular expression.
 
